@@ -1,6 +1,8 @@
 from tkinter import Tk, Widget, Listbox
 from tkscrollutil.scrollarea import ScrollArea
+from tkscrollutil.scrollsync import ScrollSync
 from tkscrollutil.ttk_scrollarea import ScrollArea as ttkScrollArea
+from tkscrollutil.ttk_scrollsync import ScrollSync as ttkScrollSync
 from tkscrollutil.load import load, load_tile
 
 
@@ -10,7 +12,9 @@ __all__ = [
     "load",
     "load_tile",
     "ScrollArea",
-    "ttkScrollArea"
+    "ScrollSync",
+    "ttkScrollArea",
+    "ttkScrollSync"
 ]
 
 STATIC = "static"
